<?php
/**
 * @package Blink
 *
 * @since 1.0.0.
 */

if ( ! function_exists( 'blink_get_font_stack' ) ) :
/**
 * Validate the font choice and get a font stack for it.
 *
 * @since  1.0.0.
 *
 * @param  string    $font    The 1st font in the stack.
 * @return string             The full font stack.
 */
function blink_get_font_stack( $font ) {
	$all_fonts = blink_get_all_fonts();

	// Sanitize font choice
	$font = blink_sanitize_font_choice( $font );

	// Standard font
	if ( isset( $all_fonts[ $font ]['stack'] ) && ! empty( $all_fonts[ $font ]['stack'] ) ) {
		$stack = $all_fonts[ $font ]['stack'];
	} elseif ( in_array( $font, blink_all_font_choices() ) ) {
		$stack = '"' . $font . '","Helvetica Neue",Helvetica,Arial,sans-serif';
	} else {
		$stack = '"Helvetica Neue",Helvetica,Arial,sans-serif';
	}

	return $stack;
}
endif;

if ( ! function_exists( 'blink_get_relative_font_size' ) ) :
/**
 * Convert a font size to a relative size based on a starting value and percentage.
 *
 * @since  1.0.0.
 *
 * @param  mixed    $value         The value to base the final value on.
 * @param  mixed    $percentage    The percentage of change.
 * @return float                   The converted value.
 */
function blink_get_relative_font_size( $value, $percentage ) {
	return (float) $value * ( $percentage / 100 );
}
endif;

if ( ! function_exists( 'blink_convert_px_to_rem' ) ) :
/**
 * Given a px value, return a rem value.
 *
 * @since  1.0.0.
 *
 * @param  mixed    $px      The value to convert.
 * @param  mixed    $base    The font-size base for the rem conversion.
 * @return float             The converted value.
 */
function blink_convert_px_to_rem( $px, $base = 0 ) {
	return (float) $px / 10;
}
endif;

if ( ! function_exists( 'blink_get_google_font_uri' ) ) :
/**
 * Build the HTTP request URL for Google Fonts.
 *
 * @since  1.0.0.
 *
 * @return string    The URL for including Google Fonts.
 */
function blink_get_google_font_uri() {
	// Grab the font choices
	$font_keys = array(
		'fonts-header',
		'fonts-body',
	);

	$fonts = array();
	foreach ( $font_keys as $key ) {
		$fonts[] = get_theme_mod( $key, blink_get_default( $key ) );
	}

	// De-dupe the fonts
	$fonts         = array_unique( $fonts );
	$allowed_fonts = blink_get_google_fonts();
	$family        = array();

	// Validate each font and convert to URL format
	foreach ( $fonts as $font ) {
		$font = trim( $font );

		// Verify that the font exists
		if ( array_key_exists( $font, $allowed_fonts ) ) {
			// Build the family name and variant string (e.g., "Open+Sans:regular,italic,700")
			$family[] = urlencode( $font . ':' . join( ',', blink_choose_google_font_variants( $font, $allowed_fonts[ $font ]['variants'] ) ) );
		}
	}

	// Convert from array to string
	if ( empty( $family ) ) {
		return '';
	} else {
		$request = '//fonts.googleapis.com/css?family=' . implode( '|', $family );
	}

	// Load the font subset
	$subset = get_theme_mod( 'fonts-subset', blink_get_default( 'fonts-subset' ) );

	if ( 'all' === $subset ) {
		$subsets_available = blink_get_google_font_subsets();

		// Remove the all set
		unset( $subsets_available['all'] );

		// Build the array
		$subsets = array_keys( $subsets_available );
	} else {
		$subsets = array(
			'latin',
			$subset,
		);
	}

	// Append the subset string
	if ( ! empty( $subsets ) ) {
		$request .= urlencode( '&subset=' . join( ',', $subsets ) );
	}

	return esc_url( $request );
}
endif;

add_filter( 'blink_font_uri', 'blink_get_google_font_uri' );

if ( ! function_exists( 'blink_choose_google_font_variants' ) ) :
/**
 * Given a font, chose the variants to load for the theme.
 *
 * Attempts to load regular, italic, and 700. If regular is not found, the first variant in the family is chosen. italic
 * and 700 are only loaded if found. No fallbacks are loaded for those fonts.
 *
 * @since  1.0.0.
 *
 * @param  string    $font        The font to load variants for.
 * @param  array     $variants    The variants for the font.
 * @return array                  The chosen variants.
 */
function blink_choose_google_font_variants( $font, $variants = array() ) {
	$chosen_variants = array();
	if ( empty( $variants ) ) {
		$fonts = blink_get_google_fonts();

		if ( array_key_exists( $font, $fonts ) ) {
			$variants = $fonts[ $font ]['variants'];
		}
	}

	// If a "regular" variant is not found, get the first variant
	if ( ! in_array( 'regular', $variants ) ) {
		$chosen_variants[] = $variants[0];
	} else {
		$chosen_variants[] = 'regular';
	}

	// Only add "italic" if it exists
	if ( in_array( 'italic', $variants ) ) {
		$chosen_variants[] = 'italic';
	}

	// Only add "700" if it exists
	if ( in_array( '700', $variants ) ) {
		$chosen_variants[] = '700';
	}

	/**
	 * Allow developers to alter the font variant choice.
	 *
	 * @since 1.0.0.
	 *
	 * @param array 	$chosen_variants 	The list of variants for a font.
	 * @param string 	$font 				The font to load variants for.
	 * @param array 	variants 			The variants for the font.
	 */
	return apply_filters( 'blink_font_variants', array_unique( $chosen_variants ), $font, $variants );
}
endif;

if ( ! function_exists( 'blink_css_fonts' ) ) :
/**
 * Build the CSS rules for the custom fonts.
 *
 * @since 1.0.0.
 *
 * @return void
 */
function blink_css_fonts() {
	$font_header          = get_theme_mod( 'fonts-header', blink_get_default( 'fonts-header' ) );
	$font_header_stack    = blink_get_font_stack( $font_header );
	$font_body            = get_theme_mod( 'fonts-body', blink_get_default( 'fonts-body' ) );
	$font_body_stack      = blink_get_font_stack( $font_body );

	if ( $font_header != blink_get_default( 'fonts-header' ) ) :
	blink_get_css()->add( array(
		'selectors'    => array(
			'h1',
			'h2',
			'h3',
			'h4',
			'h5',
			'h6',
			'th',
			'label',
			'button',
			'.button',
			'input[type="button"]',
			'input[type="reset"]',
			'input[type="submit"]',
			'.stag-button',
			'.page-links',
			'.tags-label',
			'.entry-meta',
			'.no-comments',
			'.nav-links [rel]',
			'.main-navigation',
			'.stag-toggle-title',
			'.sticky-post-label',
			'.menu-toggle__label',
			'.comment-list .comment-author',
		),
		'declarations' => array(
			'font-family' => $font_header_stack,
		)
	) );
	endif;

	if ( $font_body != blink_get_default( 'fonts-body' ) ) :
	blink_get_css()->add( array(
		'selectors'    => array( 'body', '.font-body', 'input', 'select', 'textarea', '.entry-subtitle' ),
		'declarations' => array(
			'font-family' => $font_body_stack,
		)
	) );
	endif;
}
endif;

add_action( 'blink_css', 'blink_css_fonts' );

if ( ! function_exists( 'blink_sanitize_font_subset' ) ) :
/**
 * Sanitize the Character Subset choice.
 *
 * @since  1.0.0
 *
 * @param  string    $value    The value to sanitize.
 * @return array               The sanitized value.
 */
function blink_sanitize_font_subset( $value ) {
	if ( ! array_key_exists( $value, blink_get_google_font_subsets() ) ) {
		$value = 'latin';
	}

	return $value;
}
endif;

if ( ! function_exists( 'blink_get_google_font_subsets' ) ) :
/**
 * Retrieve the list of available Google font subsets.
 *
 * @since  1.0.0.
 *
 * @return array    The available subsets.
 */
function blink_get_google_font_subsets() {
	return array(
		'all'          => esc_html__( 'All', 'blink' ),
		'arabic'       => esc_html__( 'Arabic', 'blink' ),
		'bengali'      => esc_html__( 'Bengali', 'blink' ),
		'cyrillic'     => esc_html__( 'Cyrillic', 'blink' ),
		'cyrillic-ext' => esc_html__( 'Cyrillic Extended', 'blink' ),
		'devanagari'   => esc_html__( 'Devanagari', 'blink' ),
		'greek'        => esc_html__( 'Greek', 'blink' ),
		'greek-ext'    => esc_html__( 'Greek Extended', 'blink' ),
		'gujarati'     => esc_html__( 'Gujarati', 'blink' ),
		'hebrew'       => esc_html__( 'Hebrew', 'blink' ),
		'khmer'        => esc_html__( 'Khmer', 'blink' ),
		'latin'        => esc_html__( 'Latin', 'blink' ),
		'latin-ext'    => esc_html__( 'Latin Extended', 'blink' ),
		'tamil'        => esc_html__( 'Tamil', 'blink' ),
		'telugu'       => esc_html__( 'Telugu', 'blink' ),
		'thai'         => esc_html__( 'Thai', 'blink' ),
		'vietnamese'   => esc_html__( 'Vietnamese', 'blink' ),
	);
}
endif;

if ( ! function_exists( 'blink_sanitize_font_choice' ) ) :
/**
 * Sanitize a font choice.
 *
 * @since  1.0.0.
 *
 * @param  string    $value    The font choice.
 * @return string              The sanitized font choice.
 */
function blink_sanitize_font_choice( $value ) {
	if ( is_int( $value ) ) {
		// The array key is an integer, so the chosen option is a heading, not a real choice
		return '';
	} else if ( array_key_exists( $value, blink_all_font_choices() ) ) {
		return $value;
	} else {
		return '';
	}
}
endif;

if ( ! function_exists( 'blink_get_all_fonts' ) ) :
/**
 * Compile font options from different sources.
 *
 * @since  1.0.0.
 *
 * @return array    All available fonts.
 */
function blink_get_all_fonts() {
	$heading1            = array( 1 => array( 'label' => sprintf( '&mdash; %s &mdash;', __( 'Standard Fonts', 'blink' ) ) ) );
	$standard_fonts      = blink_get_standard_fonts();

	$google_fonts        = blink_get_google_fonts();

	$serif_heading       = array( 2 => array( 'label' => sprintf( '&mdash; %s &mdash;', __( 'Serif Fonts (Google)', 'blink' ) ) ) );
	$serif_fonts         = wp_list_filter( $google_fonts, array( 'category' => 'serif' ) );

	$sans_serif_heading  = array( 3 => array( 'label' => sprintf( '&mdash; %s &mdash;', __( 'Sans Serif Fonts (Google)', 'blink' ) ) ) );
	$sans_serif_fonts    = wp_list_filter( $google_fonts, array( 'category' => 'sans-serif' ) );

	$display_heading     = array( 4 => array( 'label' => sprintf( '&mdash; %s &mdash;', __( 'Display Fonts (Google)', 'blink' ) ) ) );
	$display_fonts       = wp_list_filter( $google_fonts, array( 'category' => 'display' ) );

	$handwriting_heading = array( 4 => array( 'label' => sprintf( '&mdash; %s &mdash;', __( 'Handwriting Fonts (Google)', 'blink' ) ) ) );
	$handwriting_fonts   = wp_list_filter( $google_fonts, array( 'category' => 'handwriting' ) );

	$monospace_heading   = array( 4 => array( 'label' => sprintf( '&mdash; %s &mdash;', __( 'Monospace Fonts (Google)', 'blink' ) ) ) );
	$monospace_fonts     = wp_list_filter( $google_fonts, array( 'category' => 'monospace' ) );

	return apply_filters( 'blink_all_fonts', array_merge(
		$heading1, $standard_fonts,
		$serif_heading, $serif_fonts,
		$sans_serif_heading, $sans_serif_fonts,
		$display_heading, $display_fonts,
		$handwriting_heading, $handwriting_fonts,
		$monospace_heading, $monospace_fonts
	) );
}
endif;

if ( ! function_exists( 'blink_all_font_choices' ) ) :
/**
 * Packages the font choices into value/label pairs for use with the customizer.
 *
 * @since  1.0.0.
 *
 * @return array    The fonts in value/label pairs.
 */
function blink_all_font_choices() {
	$fonts   = blink_get_all_fonts();
	$choices = array();

	// Repackage the fonts into value/label pairs
	foreach ( $fonts as $key => $font ) {
		$choices[ $key ] = $font['label'];
	}

	return $choices;
}
endif;

if ( ! function_exists( 'blink_get_standard_fonts' ) ) :
/**
 * Return an array of standard websafe fonts.
 *
 * @since  1.0.0.
 *
 * @return array    Standard websafe fonts.
 */
function blink_get_standard_fonts() {
	return array(
		'serif' => array(
			'label' => _x( 'Serif', 'font style', 'blink' ),
			'stack' => 'Georgia,Times,"Times New Roman",serif',
		),
		'sans-serif' => array(
			'label' => _x( 'Sans Serif', 'font style', 'blink' ),
			'stack' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'monospace' => array(
			'label' => _x( 'Monospaced', 'font style', 'blink' ),
			'stack' => 'Monaco,"Lucida Sans Typewriter","Lucida Typewriter","Courier New",Courier,monospace',
		)
	);
}
endif;

